
      const require = await (async () => {
        const { createRequire } = await import("node:module");
        return createRequire(import.meta.url);
      })();
    

// src/run/headers.ts
var generateNetlifyVaryValues = ({ headers, languages, cookies }) => {
  const values = [];
  if (headers.length !== 0) {
    values.push(`header=${headers.join(`|`)}`);
  }
  if (languages.length !== 0) {
    values.push(`language=${languages.join(`|`)}`);
  }
  if (cookies.length !== 0) {
    values.push(`cookie=${cookies.join(`|`)}`);
  }
  return values.join(",");
};
var getHeaderValueArray = (header) => {
  return header.split(",").map((value) => value.trim());
};
var omitHeaderValues = (header, values) => {
  const headerValues = getHeaderValueArray(header);
  const filteredValues = headerValues.filter(
    (value) => !values.some((val) => value.startsWith(val))
  );
  return filteredValues.join(", ");
};
var mapHeaderValues = (header, callback) => {
  const headerValues = getHeaderValueArray(header);
  const mappedValues = headerValues.map(callback);
  return mappedValues.join(", ");
};
var setVaryHeaders = (headers, request, { basePath, i18n }) => {
  const netlifyVaryValues = {
    headers: [],
    languages: [],
    cookies: ["__prerender_bypass", "__next_preview_data"]
  };
  const vary = headers.get("vary");
  if (vary !== null) {
    netlifyVaryValues.headers.push(...getHeaderValueArray(vary));
  }
  const path = new URL(request.url).pathname;
  const locales = i18n && i18n.localeDetection !== false ? i18n.locales : [];
  if (locales.length > 1 && (path === "/" || path === basePath)) {
    netlifyVaryValues.languages.push(...locales);
    netlifyVaryValues.cookies.push(`NEXT_LOCALE`);
  }
  headers.set(`netlify-vary`, generateNetlifyVaryValues(netlifyVaryValues));
};
var setCacheControlHeaders = (headers) => {
  const cacheControl = headers.get("cache-control");
  if (cacheControl !== null && !headers.has("cdn-cache-control") && !headers.has("netlify-cdn-cache-control")) {
    const privateCacheControl = omitHeaderValues(cacheControl, [
      "s-maxage",
      "stale-while-revalidate"
    ]);
    const sharedCacheControl = mapHeaderValues(
      cacheControl,
      (value) => value === "stale-while-revalidate" ? "stale-while-revalidate=31536000" : value
    );
    headers.set("cache-control", privateCacheControl || "public, max-age=0, must-revalidate");
    headers.set("netlify-cdn-cache-control", sharedCacheControl);
  }
};
var setCacheTagsHeaders = (headers, request, manifest) => {
  const path = new URL(request.url).pathname;
  const tags = manifest[path];
  headers.set("cache-tag", tags);
};

export {
  setVaryHeaders,
  setCacheControlHeaders,
  setCacheTagsHeaders
};
