
      const require = await (async () => {
        const { createRequire } = await import("node:module");
        return createRequire(import.meta.url);
      })();
    
import {
  copyNextDependencies,
  copyNextServerCode,
  writeTagsManifest
} from "./chunk-JC7VU6FM.js";
import {
  require_out
} from "./chunk-AVWFCGVE.js";
import {
  PLUGIN_DIR,
  PLUGIN_NAME,
  PLUGIN_VERSION,
  SERVER_FUNCTIONS_DIR,
  SERVER_HANDLER_DIR,
  SERVER_HANDLER_NAME
} from "./chunk-IILJNFIP.js";
import {
  __toESM
} from "./chunk-RSKIKBZH.js";

// src/build/functions/server.ts
var import_fast_glob = __toESM(require_out(), 1);
import { cp, mkdir, rm, writeFile } from "fs/promises";
import { join, resolve } from "node:path";
var copyHandlerDependencies = async () => {
  const fileList = await (0, import_fast_glob.glob)("dist/**/*", { cwd: PLUGIN_DIR });
  await Promise.all(
    [...fileList].map(
      async (path) => cp(join(PLUGIN_DIR, path), resolve(SERVER_HANDLER_DIR, path), { recursive: true })
    )
  );
};
var writeHandlerManifest = async () => {
  await writeFile(
    resolve(SERVER_HANDLER_DIR, `${SERVER_HANDLER_NAME}.json`),
    JSON.stringify({
      config: {
        name: "Next.js Server Handler",
        generator: `${PLUGIN_NAME}@${PLUGIN_VERSION}`,
        nodeBundler: "none",
        includedFiles: [
          `${SERVER_HANDLER_NAME}*`,
          "package.json",
          "dist/**",
          ".next/**",
          ".netlify/**",
          "node_modules/**"
        ],
        includedFilesBasePath: resolve(SERVER_HANDLER_DIR)
      },
      version: 1
    }),
    "utf-8"
  );
};
var writePackageMetadata = async () => {
  await writeFile(resolve(SERVER_HANDLER_DIR, "package.json"), JSON.stringify({ type: "module" }));
};
var writeHandlerFile = async () => {
  await writeFile(
    resolve(SERVER_HANDLER_DIR, `${SERVER_HANDLER_NAME}.js`),
    `import handler from './dist/run/handlers/server.js';export default handler`
  );
};
var createServerHandler = async ({
  constants
}) => {
  await rm(resolve(SERVER_FUNCTIONS_DIR), { recursive: true, force: true });
  await mkdir(resolve(SERVER_HANDLER_DIR, ".netlify"), { recursive: true });
  await Promise.all([
    copyNextServerCode({ constants }),
    copyNextDependencies({ constants }),
    writeTagsManifest({ constants }),
    copyHandlerDependencies(),
    writeHandlerManifest(),
    writePackageMetadata(),
    writeHandlerFile()
  ]);
};

export {
  createServerHandler
};
