
      const require = await (async () => {
        const { createRequire } = await import("node:module");
        return createRequire(import.meta.url);
      })();
    
import {
  require_out
} from "./chunk-AVWFCGVE.js";
import {
  getPrerenderManifest
} from "./chunk-XI354FB5.js";
import {
  BLOB_DIR
} from "./chunk-IILJNFIP.js";
import {
  __toESM
} from "./chunk-RSKIKBZH.js";

// src/build/content/prerendered.ts
var import_fast_glob = __toESM(require_out(), 1);
import { mkdir, readFile, writeFile } from "node:fs/promises";
import { basename, dirname, extname, resolve } from "node:path";
import { join as joinPosix } from "node:path/posix";
var isPage = (key, routes) => {
  return key.startsWith("server/pages") && routes.includes(key.replace(/^server\/pages/, ""));
};
var isApp = (path) => {
  return path.startsWith("server/app") && extname(path) === ".html";
};
var isRoute = (path) => {
  return path.startsWith("server/app") && extname(path) === ".body";
};
var isFetch = (path) => {
  return path.startsWith("cache/fetch-cache") && extname(path) === "";
};
var buildPrerenderedContentEntries = async (src, routes) => {
  const paths = await (0, import_fast_glob.default)([`cache/fetch-cache/*`, `server/+(app|pages)/**/*.+(html|body)`], {
    cwd: resolve(src),
    extglob: true
  });
  return paths.map(async (path) => {
    const key = joinPosix(dirname(path), basename(path, extname(path)));
    let value;
    if (isPage(key, routes)) {
      value = {
        kind: "PAGE",
        html: await readFile(resolve(src, `${key}.html`), "utf-8"),
        pageData: JSON.parse(await readFile(resolve(src, `${key}.json`), "utf-8"))
      };
    }
    if (isApp(path)) {
      value = {
        kind: "PAGE",
        html: await readFile(resolve(src, `${key}.html`), "utf-8"),
        pageData: await readFile(resolve(src, `${key}.rsc`), "utf-8"),
        ...JSON.parse(await readFile(resolve(src, `${key}.meta`), "utf-8"))
      };
    }
    if (isRoute(path)) {
      value = {
        kind: "ROUTE",
        body: await readFile(resolve(src, `${key}.body`), "utf-8"),
        ...JSON.parse(await readFile(resolve(src, `${key}.meta`), "utf-8"))
      };
    }
    if (isFetch(path)) {
      value = {
        kind: "FETCH",
        ...JSON.parse(await readFile(resolve(src, key), "utf-8"))
      };
    }
    return {
      key,
      value: {
        lastModified: Date.now(),
        value
      }
    };
  });
};
var uploadPrerenderedContent = async ({
  constants: { PUBLISH_DIR },
  utils
}) => {
  try {
    const manifest = await getPrerenderManifest({ PUBLISH_DIR });
    const entries = await Promise.all(
      await buildPrerenderedContentEntries(PUBLISH_DIR, Object.keys(manifest.routes))
    );
    await Promise.all(
      entries.filter((entry) => entry.value.value !== void 0).map(async (entry) => {
        const dest = resolve(BLOB_DIR, entry.key);
        await mkdir(dirname(dest), { recursive: true });
        await writeFile(resolve(BLOB_DIR, entry.key), JSON.stringify(entry.value), "utf-8");
      })
    );
  } catch (error) {
    utils.build.failBuild(
      "Failed assembling prerendered content for upload",
      error instanceof Error ? { error } : {}
    );
    throw error;
  }
};

export {
  uploadPrerenderedContent
};
