
      const require = await (async () => {
        const { createRequire } = await import("node:module");
        return createRequire(import.meta.url);
      })();
    
import {
  getMiddlewareManifest
} from "./chunk-XI354FB5.js";
import {
  EDGE_FUNCTIONS_DIR,
  EDGE_HANDLER_NAME,
  PLUGIN_DIR,
  PLUGIN_NAME,
  PLUGIN_VERSION
} from "./chunk-IILJNFIP.js";

// src/build/functions/edge.ts
import { cp, mkdir, readFile, rm, writeFile } from "node:fs/promises";
import { dirname, join, relative, resolve } from "node:path";
var getHandlerName = ({ name }) => EDGE_HANDLER_NAME.replace("{{name}}", name.replace(/\W/g, "-"));
var buildHandlerDefinitions = ({ name: definitionName, matchers, page }, handlerName) => {
  return definitionName === "middleware" ? [
    {
      function: handlerName,
      name: "Next.js Middleware Handler",
      path: "/*",
      generator: `${PLUGIN_NAME}@${PLUGIN_VERSION}`
    }
  ] : matchers.map((matcher) => ({
    function: handlerName,
    name: `Next.js Edge Handler: ${page}`,
    pattern: matcher.regexp,
    cache: "manual",
    generator: `${PLUGIN_NAME}@${PLUGIN_VERSION}`
  }));
};
var copyHandlerDependencies = async ({ name: definitionName, files }, handlerName) => {
  await Promise.all(
    files.map(async (file) => {
      const srcDir = join(process.cwd(), ".next/standalone/.next");
      const destDir = join(process.cwd(), EDGE_FUNCTIONS_DIR, handlerName);
      if (file === `server/${definitionName}.js`) {
        const entrypoint = await readFile(join(srcDir, file), "utf8");
        const exports = `
        export default _ENTRIES["middleware_${definitionName}"].default;
        // export default () => {

        // console.log('here', _ENTRIES)
        // }
        `;
        await mkdir(dirname(join(destDir, file)), { recursive: true });
        await writeFile(
          join(destDir, file),
          `
          import './edge-runtime-webpack.js';


          var _ENTRIES = {};
`.concat(entrypoint, "\n", exports)
        );
        return;
      }
      await cp(join(srcDir, file), join(destDir, file));
    })
  );
};
var writeHandlerFile = async ({ name: definitionName }, handlerName) => {
  const handlerFile = resolve(EDGE_FUNCTIONS_DIR, handlerName, `${handlerName}.js`);
  const rel = relative(handlerFile, join(PLUGIN_DIR, "dist/run/handlers/middleware.js"));
  await cp(
    join(PLUGIN_DIR, "edge-runtime"),
    resolve(EDGE_FUNCTIONS_DIR, handlerName, "edge-runtime"),
    {
      recursive: true
    }
  );
  await writeFile(
    resolve(EDGE_FUNCTIONS_DIR, handlerName, `${handlerName}.js`),
    `import {handleMiddleware} from './edge-runtime/middleware.ts';
    import handler from './server/${definitionName}.js';
    export default (req, context) => handleMiddleware(req, context, handler);
    export const config = {path: "/*"}`
  );
};
var writeEdgeManifest = async (manifest) => {
  await mkdir(resolve(EDGE_FUNCTIONS_DIR), { recursive: true });
  await writeFile(resolve(EDGE_FUNCTIONS_DIR, "manifest.json"), JSON.stringify(manifest, null, 2));
};
var createEdgeHandlers = async () => {
  await rm(EDGE_FUNCTIONS_DIR, { recursive: true, force: true });
  const nextManifest = await getMiddlewareManifest();
  const nextDefinitions = [
    ...Object.values(nextManifest.middleware)
    // ...Object.values(nextManifest.functions)
  ];
  const netlifyManifest = {
    version: 1,
    functions: await nextDefinitions.reduce(
      async (netlifyDefinitions, nextDefinition) => {
        const handlerName = getHandlerName(nextDefinition);
        await copyHandlerDependencies(nextDefinition, handlerName);
        await writeHandlerFile(nextDefinition, handlerName);
        return [
          ...await netlifyDefinitions,
          ...buildHandlerDefinitions(nextDefinition, handlerName)
        ];
      },
      Promise.resolve([])
    )
  };
  await writeEdgeManifest(netlifyManifest);
};

export {
  createEdgeHandlers
};
